@@ -37,6 +37,7 @@
 #include <gcr/gcr-certificate.h>
 #include <gcr/gcr-certificate-chain.h>
 #include <gcr/gcr-certificate-request.h>
+#include <gcr/gcr-column.h>
 #include <gcr/gcr-deprecated-base.h>
 #include <gcr/gcr-enum-types-base.h>
 #include <gcr/gcr-filter-collection.h>
@@ -48,6 +49,7 @@
 #include <gcr/gcr-pkcs11-certificate.h>
 #include <gcr/gcr-prompt.h>
 #include <gcr/gcr-secret-exchange.h>
+#include <gcr/gcr-secure-memory.h>
 #include <gcr/gcr-simple-certificate.h>
 #include <gcr/gcr-simple-collection.h>
 #include <gcr/gcr-system-prompt.h>
